You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@commons.apache.org by ba...@apache.org on 2009/12/10 12:57:29 UTC

svn commit: r889215 [2/3] - in /commons/proper/lang/trunk/src: java/org/apache/commons/lang3/ java/org/apache/commons/lang3/builder/ java/org/apache/commons/lang3/concurrent/ java/org/apache/commons/lang3/exception/ java/org/apache/commons/lang3/math/ ...

Modified: commons/proper/lang/trunk/src/test/org/apache/commons/lang3/ArrayUtilsTest.java
URL: http://svn.apache.org/viewvc/commons/proper/lang/trunk/src/test/org/apache/commons/lang3/ArrayUtilsTest.java?rev=889215&r1=889214&r2=889215&view=diff
==============================================================================
--- commons/proper/lang/trunk/src/test/org/apache/commons/lang3/ArrayUtilsTest.java (original)
+++ commons/proper/lang/trunk/src/test/org/apache/commons/lang3/ArrayUtilsTest.java Thu Dec 10 11:56:38 2009
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.lang;
+package org.apache.commons.lang3;
 
 import java.lang.reflect.Constructor;
 import java.lang.reflect.Modifier;

Modified: commons/proper/lang/trunk/src/test/org/apache/commons/lang3/BitFieldTest.java
URL: http://svn.apache.org/viewvc/commons/proper/lang/trunk/src/test/org/apache/commons/lang3/BitFieldTest.java?rev=889215&r1=889214&r2=889215&view=diff
==============================================================================
--- commons/proper/lang/trunk/src/test/org/apache/commons/lang3/BitFieldTest.java (original)
+++ commons/proper/lang/trunk/src/test/org/apache/commons/lang3/BitFieldTest.java Thu Dec 10 11:56:38 2009
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.lang;
+package org.apache.commons.lang3;
 
 import junit.framework.Test;
 import junit.framework.TestCase;

Modified: commons/proper/lang/trunk/src/test/org/apache/commons/lang3/BooleanUtilsTest.java
URL: http://svn.apache.org/viewvc/commons/proper/lang/trunk/src/test/org/apache/commons/lang3/BooleanUtilsTest.java?rev=889215&r1=889214&r2=889215&view=diff
==============================================================================
--- commons/proper/lang/trunk/src/test/org/apache/commons/lang3/BooleanUtilsTest.java (original)
+++ commons/proper/lang/trunk/src/test/org/apache/commons/lang3/BooleanUtilsTest.java Thu Dec 10 11:56:38 2009
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.lang;
+package org.apache.commons.lang3;
 
 import java.lang.reflect.Constructor;
 import java.lang.reflect.Modifier;

Modified: commons/proper/lang/trunk/src/test/org/apache/commons/lang3/CharEncodingTest.java
URL: http://svn.apache.org/viewvc/commons/proper/lang/trunk/src/test/org/apache/commons/lang3/CharEncodingTest.java?rev=889215&r1=889214&r2=889215&view=diff
==============================================================================
--- commons/proper/lang/trunk/src/test/org/apache/commons/lang3/CharEncodingTest.java (original)
+++ commons/proper/lang/trunk/src/test/org/apache/commons/lang3/CharEncodingTest.java Thu Dec 10 11:56:38 2009
@@ -15,7 +15,7 @@
  * limitations under the License.
  */
 
-package org.apache.commons.lang;
+package org.apache.commons.lang3;
 
 import junit.framework.Test;
 import junit.framework.TestCase;

Modified: commons/proper/lang/trunk/src/test/org/apache/commons/lang3/CharRangeTest.java
URL: http://svn.apache.org/viewvc/commons/proper/lang/trunk/src/test/org/apache/commons/lang3/CharRangeTest.java?rev=889215&r1=889214&r2=889215&view=diff
==============================================================================
--- commons/proper/lang/trunk/src/test/org/apache/commons/lang3/CharRangeTest.java (original)
+++ commons/proper/lang/trunk/src/test/org/apache/commons/lang3/CharRangeTest.java Thu Dec 10 11:56:38 2009
@@ -16,7 +16,7 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package org.apache.commons.lang;
+package org.apache.commons.lang3;
 
 import java.lang.reflect.Modifier;
 

Modified: commons/proper/lang/trunk/src/test/org/apache/commons/lang3/CharSetTest.java
URL: http://svn.apache.org/viewvc/commons/proper/lang/trunk/src/test/org/apache/commons/lang3/CharSetTest.java?rev=889215&r1=889214&r2=889215&view=diff
==============================================================================
--- commons/proper/lang/trunk/src/test/org/apache/commons/lang3/CharSetTest.java (original)
+++ commons/proper/lang/trunk/src/test/org/apache/commons/lang3/CharSetTest.java Thu Dec 10 11:56:38 2009
@@ -16,7 +16,7 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package org.apache.commons.lang;
+package org.apache.commons.lang3;
 
 import java.lang.reflect.Modifier;
 

Modified: commons/proper/lang/trunk/src/test/org/apache/commons/lang3/CharSetUtilsTest.java
URL: http://svn.apache.org/viewvc/commons/proper/lang/trunk/src/test/org/apache/commons/lang3/CharSetUtilsTest.java?rev=889215&r1=889214&r2=889215&view=diff
==============================================================================
--- commons/proper/lang/trunk/src/test/org/apache/commons/lang3/CharSetUtilsTest.java (original)
+++ commons/proper/lang/trunk/src/test/org/apache/commons/lang3/CharSetUtilsTest.java Thu Dec 10 11:56:38 2009
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.lang;
+package org.apache.commons.lang3;
 
 import java.lang.reflect.Constructor;
 import java.lang.reflect.Modifier;

Modified: commons/proper/lang/trunk/src/test/org/apache/commons/lang3/CharUtilsPerfRun.java
URL: http://svn.apache.org/viewvc/commons/proper/lang/trunk/src/test/org/apache/commons/lang3/CharUtilsPerfRun.java?rev=889215&r1=889214&r2=889215&view=diff
==============================================================================
--- commons/proper/lang/trunk/src/test/org/apache/commons/lang3/CharUtilsPerfRun.java (original)
+++ commons/proper/lang/trunk/src/test/org/apache/commons/lang3/CharUtilsPerfRun.java Thu Dec 10 11:56:38 2009
@@ -15,7 +15,7 @@
  * limitations under the License.
  */
 
-package org.apache.commons.lang;
+package org.apache.commons.lang3;
 
 import java.text.NumberFormat;
 import java.util.Calendar;

Modified: commons/proper/lang/trunk/src/test/org/apache/commons/lang3/CharUtilsTest.java
URL: http://svn.apache.org/viewvc/commons/proper/lang/trunk/src/test/org/apache/commons/lang3/CharUtilsTest.java?rev=889215&r1=889214&r2=889215&view=diff
==============================================================================
--- commons/proper/lang/trunk/src/test/org/apache/commons/lang3/CharUtilsTest.java (original)
+++ commons/proper/lang/trunk/src/test/org/apache/commons/lang3/CharUtilsTest.java Thu Dec 10 11:56:38 2009
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.lang;
+package org.apache.commons.lang3;
 
 import java.lang.reflect.Constructor;
 import java.lang.reflect.Modifier;

Modified: commons/proper/lang/trunk/src/test/org/apache/commons/lang3/ClassUtilsTest.java
URL: http://svn.apache.org/viewvc/commons/proper/lang/trunk/src/test/org/apache/commons/lang3/ClassUtilsTest.java?rev=889215&r1=889214&r2=889215&view=diff
==============================================================================
--- commons/proper/lang/trunk/src/test/org/apache/commons/lang3/EnumUtilsTest.java (original)
+++ commons/proper/lang/trunk/src/test/org/apache/commons/lang3/EnumUtilsTest.java Thu Dec 10 11:56:38 2009
@@ -16,7 +16,7 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package org.apache.commons.lang;
+package org.apache.commons.lang3;
 
 import java.util.List;
 import java.util.Map;

Modified: commons/proper/lang/trunk/src/test/org/apache/commons/lang3/LocaleUtilsTest.java
URL: http://svn.apache.org/viewvc/commons/proper/lang/trunk/src/test/org/apache/commons/lang3/LocaleUtilsTest.java?rev=889215&r1=889214&r2=889215&view=diff
==============================================================================
--- commons/proper/lang/trunk/src/test/org/apache/commons/lang3/LocaleUtilsTest.java (original)
+++ commons/proper/lang/trunk/src/test/org/apache/commons/lang3/LocaleUtilsTest.java Thu Dec 10 11:56:38 2009
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.lang;
+package org.apache.commons.lang3;
 
 import java.lang.reflect.Constructor;
 import java.lang.reflect.Modifier;

Modified: commons/proper/lang/trunk/src/test/org/apache/commons/lang3/ObjectUtilsTest.java
URL: http://svn.apache.org/viewvc/commons/proper/lang/trunk/src/test/org/apache/commons/lang3/ObjectUtilsTest.java?rev=889215&r1=889214&r2=889215&view=diff
==============================================================================
--- commons/proper/lang/trunk/src/test/org/apache/commons/lang3/ObjectUtilsTest.java (original)
+++ commons/proper/lang/trunk/src/test/org/apache/commons/lang3/ObjectUtilsTest.java Thu Dec 10 11:56:38 2009
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.lang;
+package org.apache.commons.lang3;
 
 import java.lang.reflect.Constructor;
 import java.lang.reflect.Modifier;

Modified: commons/proper/lang/trunk/src/test/org/apache/commons/lang3/RandomStringUtilsTest.java
URL: http://svn.apache.org/viewvc/commons/proper/lang/trunk/src/test/org/apache/commons/lang3/RandomStringUtilsTest.java?rev=889215&r1=889214&r2=889215&view=diff
==============================================================================
--- commons/proper/lang/trunk/src/test/org/apache/commons/lang3/RandomStringUtilsTest.java (original)
+++ commons/proper/lang/trunk/src/test/org/apache/commons/lang3/RandomStringUtilsTest.java Thu Dec 10 11:56:38 2009
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.lang;
+package org.apache.commons.lang3;
 
 import java.lang.reflect.Constructor;
 import java.lang.reflect.Modifier;

Modified: commons/proper/lang/trunk/src/test/org/apache/commons/lang3/RangeTest.java
URL: http://svn.apache.org/viewvc/commons/proper/lang/trunk/src/test/org/apache/commons/lang3/RangeTest.java?rev=889215&r1=889214&r2=889215&view=diff
==============================================================================
--- commons/proper/lang/trunk/src/test/org/apache/commons/lang3/RangeTest.java (original)
+++ commons/proper/lang/trunk/src/test/org/apache/commons/lang3/RangeTest.java Thu Dec 10 11:56:38 2009
@@ -15,7 +15,7 @@
  * limitations under the License.
  */
 
-package org.apache.commons.lang;
+package org.apache.commons.lang3;
 
 import java.util.Comparator;
 

Modified: commons/proper/lang/trunk/src/test/org/apache/commons/lang3/SerializationUtilsTest.java
URL: http://svn.apache.org/viewvc/commons/proper/lang/trunk/src/test/org/apache/commons/lang3/SerializationUtilsTest.java?rev=889215&r1=889214&r2=889215&view=diff
==============================================================================
--- commons/proper/lang/trunk/src/test/org/apache/commons/lang3/SerializationUtilsTest.java (original)
+++ commons/proper/lang/trunk/src/test/org/apache/commons/lang3/SerializationUtilsTest.java Thu Dec 10 11:56:38 2009
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.lang;
+package org.apache.commons.lang3;
 
 import java.io.ByteArrayInputStream;
 import java.io.ByteArrayOutputStream;

Modified: commons/proper/lang/trunk/src/test/org/apache/commons/lang3/StringEscapeUtilsTest.java
URL: http://svn.apache.org/viewvc/commons/proper/lang/trunk/src/test/org/apache/commons/lang3/StringEscapeUtilsTest.java?rev=889215&r1=889214&r2=889215&view=diff
==============================================================================
--- commons/proper/lang/trunk/src/test/org/apache/commons/lang3/StringEscapeUtilsTest.java (original)
+++ commons/proper/lang/trunk/src/test/org/apache/commons/lang3/StringEscapeUtilsTest.java Thu Dec 10 11:56:38 2009
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.lang;
+package org.apache.commons.lang3;
 
 import java.io.IOException;
 import java.io.StringWriter;

Modified: commons/proper/lang/trunk/src/test/org/apache/commons/lang3/StringUtilsEqualsIndexOfTest.java
URL: http://svn.apache.org/viewvc/commons/proper/lang/trunk/src/test/org/apache/commons/lang3/StringUtilsEqualsIndexOfTest.java?rev=889215&r1=889214&r2=889215&view=diff
==============================================================================
--- commons/proper/lang/trunk/src/test/org/apache/commons/lang3/StringUtilsEqualsIndexOfTest.java (original)
+++ commons/proper/lang/trunk/src/test/org/apache/commons/lang3/StringUtilsEqualsIndexOfTest.java Thu Dec 10 11:56:38 2009
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.lang;
+package org.apache.commons.lang3;
 
 import java.util.Locale;
 

Modified: commons/proper/lang/trunk/src/test/org/apache/commons/lang3/StringUtilsIsTest.java
URL: http://svn.apache.org/viewvc/commons/proper/lang/trunk/src/test/org/apache/commons/lang3/StringUtilsIsTest.java?rev=889215&r1=889214&r2=889215&view=diff
==============================================================================
--- commons/proper/lang/trunk/src/test/org/apache/commons/lang3/StringUtilsIsTest.java (original)
+++ commons/proper/lang/trunk/src/test/org/apache/commons/lang3/StringUtilsIsTest.java Thu Dec 10 11:56:38 2009
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.lang;
+package org.apache.commons.lang3;
 
 import junit.framework.Test;
 import junit.framework.TestCase;

Modified: commons/proper/lang/trunk/src/test/org/apache/commons/lang3/StringUtilsStartsEndsWithTest.java
URL: http://svn.apache.org/viewvc/commons/proper/lang/trunk/src/test/org/apache/commons/lang3/StringUtilsStartsEndsWithTest.java?rev=889215&r1=889214&r2=889215&view=diff
==============================================================================
--- commons/proper/lang/trunk/src/test/org/apache/commons/lang3/StringUtilsStartsEndsWithTest.java (original)
+++ commons/proper/lang/trunk/src/test/org/apache/commons/lang3/StringUtilsStartsEndsWithTest.java Thu Dec 10 11:56:38 2009
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.lang;
+package org.apache.commons.lang3;
 
 import junit.framework.Test;
 import junit.framework.TestCase;

Modified: commons/proper/lang/trunk/src/test/org/apache/commons/lang3/StringUtilsSubstringTest.java
URL: http://svn.apache.org/viewvc/commons/proper/lang/trunk/src/test/org/apache/commons/lang3/StringUtilsSubstringTest.java?rev=889215&r1=889214&r2=889215&view=diff
==============================================================================
--- commons/proper/lang/trunk/src/test/org/apache/commons/lang3/StringUtilsSubstringTest.java (original)
+++ commons/proper/lang/trunk/src/test/org/apache/commons/lang3/StringUtilsSubstringTest.java Thu Dec 10 11:56:38 2009
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.lang;
+package org.apache.commons.lang3;
 
 import junit.framework.Test;
 import junit.framework.TestCase;

Modified: commons/proper/lang/trunk/src/test/org/apache/commons/lang3/StringUtilsTest.java
URL: http://svn.apache.org/viewvc/commons/proper/lang/trunk/src/test/org/apache/commons/lang3/StringUtilsTest.java?rev=889215&r1=889214&r2=889215&view=diff
==============================================================================
--- commons/proper/lang/trunk/src/test/org/apache/commons/lang3/StringUtilsTest.java (original)
+++ commons/proper/lang/trunk/src/test/org/apache/commons/lang3/StringUtilsTest.java Thu Dec 10 11:56:38 2009
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.lang;
+package org.apache.commons.lang3;
 
 import java.lang.reflect.Constructor;
 import java.lang.reflect.Modifier;

Modified: commons/proper/lang/trunk/src/test/org/apache/commons/lang3/StringUtilsTrimEmptyTest.java
URL: http://svn.apache.org/viewvc/commons/proper/lang/trunk/src/test/org/apache/commons/lang3/StringUtilsTrimEmptyTest.java?rev=889215&r1=889214&r2=889215&view=diff
==============================================================================
--- commons/proper/lang/trunk/src/test/org/apache/commons/lang3/StringUtilsTrimEmptyTest.java (original)
+++ commons/proper/lang/trunk/src/test/org/apache/commons/lang3/StringUtilsTrimEmptyTest.java Thu Dec 10 11:56:38 2009
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.lang;
+package org.apache.commons.lang3;
 
 import junit.framework.Test;
 import junit.framework.TestCase;

Modified: commons/proper/lang/trunk/src/test/org/apache/commons/lang3/SystemUtilsTest.java
URL: http://svn.apache.org/viewvc/commons/proper/lang/trunk/src/test/org/apache/commons/lang3/SystemUtilsTest.java?rev=889215&r1=889214&r2=889215&view=diff
==============================================================================
--- commons/proper/lang/trunk/src/test/org/apache/commons/lang3/SystemUtilsTest.java (original)
+++ commons/proper/lang/trunk/src/test/org/apache/commons/lang3/SystemUtilsTest.java Thu Dec 10 11:56:38 2009
@@ -17,7 +17,7 @@
  * under the License.
  */
 
-package org.apache.commons.lang;
+package org.apache.commons.lang3;
 
 import java.io.File;
 import java.lang.reflect.Constructor;

Modified: commons/proper/lang/trunk/src/test/org/apache/commons/lang3/ValidateTest.java
URL: http://svn.apache.org/viewvc/commons/proper/lang/trunk/src/test/org/apache/commons/lang3/ValidateTest.java?rev=889215&r1=889214&r2=889215&view=diff
==============================================================================
--- commons/proper/lang/trunk/src/test/org/apache/commons/lang3/ValidateTest.java (original)
+++ commons/proper/lang/trunk/src/test/org/apache/commons/lang3/ValidateTest.java Thu Dec 10 11:56:38 2009
@@ -16,7 +16,7 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package org.apache.commons.lang;
+package org.apache.commons.lang3;
 
 import java.lang.reflect.Constructor;
 import java.lang.reflect.Modifier;

Modified: commons/proper/lang/trunk/src/test/org/apache/commons/lang3/WordUtilsTest.java
URL: http://svn.apache.org/viewvc/commons/proper/lang/trunk/src/test/org/apache/commons/lang3/WordUtilsTest.java?rev=889215&r1=889214&r2=889215&view=diff
==============================================================================
--- commons/proper/lang/trunk/src/test/org/apache/commons/lang3/WordUtilsTest.java (original)
+++ commons/proper/lang/trunk/src/test/org/apache/commons/lang3/WordUtilsTest.java Thu Dec 10 11:56:38 2009
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.lang;
+package org.apache.commons.lang3;
 
 import java.lang.reflect.Constructor;
 import java.lang.reflect.Modifier;

Modified: commons/proper/lang/trunk/src/test/org/apache/commons/lang3/builder/CompareToBuilderTest.java
URL: http://svn.apache.org/viewvc/commons/proper/lang/trunk/src/test/org/apache/commons/lang3/builder/CompareToBuilderTest.java?rev=889215&r1=889214&r2=889215&view=diff
==============================================================================
--- commons/proper/lang/trunk/src/test/org/apache/commons/lang3/builder/CompareToBuilderTest.java (original)
+++ commons/proper/lang/trunk/src/test/org/apache/commons/lang3/builder/CompareToBuilderTest.java Thu Dec 10 11:56:38 2009
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.lang.builder;
+package org.apache.commons.lang3.builder;
 
 import java.math.BigInteger;
 

Modified: commons/proper/lang/trunk/src/test/org/apache/commons/lang3/builder/DefaultToStringStyleTest.java
URL: http://svn.apache.org/viewvc/commons/proper/lang/trunk/src/test/org/apache/commons/lang3/builder/DefaultToStringStyleTest.java?rev=889215&r1=889214&r2=889215&view=diff
==============================================================================
--- commons/proper/lang/trunk/src/test/org/apache/commons/lang3/builder/DefaultToStringStyleTest.java (original)
+++ commons/proper/lang/trunk/src/test/org/apache/commons/lang3/builder/DefaultToStringStyleTest.java Thu Dec 10 11:56:38 2009
@@ -14,12 +14,12 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.lang.builder;
+package org.apache.commons.lang3.builder;
 
 import java.util.ArrayList;
 import java.util.HashMap;
 
-import org.apache.commons.lang.builder.ToStringStyleTest.Person;
+import org.apache.commons.lang3.builder.ToStringStyleTest.Person;
 
 import junit.framework.Test;
 import junit.framework.TestCase;

Modified: commons/proper/lang/trunk/src/test/org/apache/commons/lang3/builder/EqualsBuilderTest.java
URL: http://svn.apache.org/viewvc/commons/proper/lang/trunk/src/test/org/apache/commons/lang3/builder/EqualsBuilderTest.java?rev=889215&r1=889214&r2=889215&view=diff
==============================================================================
--- commons/proper/lang/trunk/src/test/org/apache/commons/lang3/builder/EqualsBuilderTest.java (original)
+++ commons/proper/lang/trunk/src/test/org/apache/commons/lang3/builder/EqualsBuilderTest.java Thu Dec 10 11:56:38 2009
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.lang.builder;
+package org.apache.commons.lang3.builder;
 
 import java.util.Arrays;
 

Modified: commons/proper/lang/trunk/src/test/org/apache/commons/lang3/builder/HashCodeBuilderAndEqualsBuilderTest.java
URL: http://svn.apache.org/viewvc/commons/proper/lang/trunk/src/test/org/apache/commons/lang3/builder/HashCodeBuilderAndEqualsBuilderTest.java?rev=889215&r1=889214&r2=889215&view=diff
==============================================================================
--- commons/proper/lang/trunk/src/test/org/apache/commons/lang3/builder/HashCodeBuilderAndEqualsBuilderTest.java (original)
+++ commons/proper/lang/trunk/src/test/org/apache/commons/lang3/builder/HashCodeBuilderAndEqualsBuilderTest.java Thu Dec 10 11:56:38 2009
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.lang.builder;
+package org.apache.commons.lang3.builder;
 
 import junit.framework.Test;
 import junit.framework.TestCase;

Modified: commons/proper/lang/trunk/src/test/org/apache/commons/lang3/builder/HashCodeBuilderTest.java
URL: http://svn.apache.org/viewvc/commons/proper/lang/trunk/src/test/org/apache/commons/lang3/builder/HashCodeBuilderTest.java?rev=889215&r1=889214&r2=889215&view=diff
==============================================================================
--- commons/proper/lang/trunk/src/test/org/apache/commons/lang3/builder/HashCodeBuilderTest.java (original)
+++ commons/proper/lang/trunk/src/test/org/apache/commons/lang3/builder/HashCodeBuilderTest.java Thu Dec 10 11:56:38 2009
@@ -15,7 +15,7 @@
  * limitations under the License.
  */
 
-package org.apache.commons.lang.builder;
+package org.apache.commons.lang3.builder;
 
 import junit.framework.Test;
 import junit.framework.TestCase;

Modified: commons/proper/lang/trunk/src/test/org/apache/commons/lang3/builder/MultiLineToStringStyleTest.java
URL: http://svn.apache.org/viewvc/commons/proper/lang/trunk/src/test/org/apache/commons/lang3/builder/MultiLineToStringStyleTest.java?rev=889215&r1=889214&r2=889215&view=diff
==============================================================================
--- commons/proper/lang/trunk/src/test/org/apache/commons/lang3/builder/MultiLineToStringStyleTest.java (original)
+++ commons/proper/lang/trunk/src/test/org/apache/commons/lang3/builder/MultiLineToStringStyleTest.java Thu Dec 10 11:56:38 2009
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.lang.builder;
+package org.apache.commons.lang3.builder;
 
 import java.util.ArrayList;
 import java.util.HashMap;
@@ -24,8 +24,8 @@
 import junit.framework.TestSuite;
 import junit.textui.TestRunner;
 
-import org.apache.commons.lang.SystemUtils;
-import org.apache.commons.lang.builder.ToStringStyleTest.Person;
+import org.apache.commons.lang3.SystemUtils;
+import org.apache.commons.lang3.builder.ToStringStyleTest.Person;
 
 /**
  * Unit tests {@link org.apache.commons.lang.builder.MultiLineToStringStyleTest}.

Modified: commons/proper/lang/trunk/src/test/org/apache/commons/lang3/builder/NoFieldNamesToStringStyleTest.java
URL: http://svn.apache.org/viewvc/commons/proper/lang/trunk/src/test/org/apache/commons/lang3/builder/NoFieldNamesToStringStyleTest.java?rev=889215&r1=889214&r2=889215&view=diff
==============================================================================
--- commons/proper/lang/trunk/src/test/org/apache/commons/lang3/builder/NoFieldNamesToStringStyleTest.java (original)
+++ commons/proper/lang/trunk/src/test/org/apache/commons/lang3/builder/NoFieldNamesToStringStyleTest.java Thu Dec 10 11:56:38 2009
@@ -14,12 +14,12 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.lang.builder;
+package org.apache.commons.lang3.builder;
 
 import java.util.ArrayList;
 import java.util.HashMap;
 
-import org.apache.commons.lang.builder.ToStringStyleTest.Person;
+import org.apache.commons.lang3.builder.ToStringStyleTest.Person;
 
 import junit.framework.Test;
 import junit.framework.TestCase;

Modified: commons/proper/lang/trunk/src/test/org/apache/commons/lang3/builder/ReflectionToStringBuilderExcludeTest.java
URL: http://svn.apache.org/viewvc/commons/proper/lang/trunk/src/test/org/apache/commons/lang3/builder/ReflectionToStringBuilderExcludeTest.java?rev=889215&r1=889214&r2=889215&view=diff
==============================================================================
--- commons/proper/lang/trunk/src/test/org/apache/commons/lang3/builder/ReflectionToStringBuilderExcludeTest.java (original)
+++ commons/proper/lang/trunk/src/test/org/apache/commons/lang3/builder/ReflectionToStringBuilderExcludeTest.java Thu Dec 10 11:56:38 2009
@@ -15,7 +15,7 @@
  * limitations under the License.
  */
 
-package org.apache.commons.lang.builder;
+package org.apache.commons.lang3.builder;
 
 import java.util.ArrayList;
 import java.util.Collection;
@@ -24,7 +24,7 @@
 import junit.framework.Assert;
 import junit.framework.TestCase;
 
-import org.apache.commons.lang.ArrayUtils;
+import org.apache.commons.lang3.ArrayUtils;
 
 /**
  * @author <a href="mailto:ggregory@seagullsw.com">ggregory</a>

Modified: commons/proper/lang/trunk/src/test/org/apache/commons/lang3/builder/ShortPrefixToStringStyleTest.java
URL: http://svn.apache.org/viewvc/commons/proper/lang/trunk/src/test/org/apache/commons/lang3/builder/ShortPrefixToStringStyleTest.java?rev=889215&r1=889214&r2=889215&view=diff
==============================================================================
--- commons/proper/lang/trunk/src/test/org/apache/commons/lang3/builder/ShortPrefixToStringStyleTest.java (original)
+++ commons/proper/lang/trunk/src/test/org/apache/commons/lang3/builder/ShortPrefixToStringStyleTest.java Thu Dec 10 11:56:38 2009
@@ -14,12 +14,12 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.lang.builder;
+package org.apache.commons.lang3.builder;
 
 import java.util.ArrayList;
 import java.util.HashMap;
 
-import org.apache.commons.lang.builder.ToStringStyleTest.Person;
+import org.apache.commons.lang3.builder.ToStringStyleTest.Person;
 
 import junit.framework.TestCase;
 

Modified: commons/proper/lang/trunk/src/test/org/apache/commons/lang3/builder/SimpleToStringStyleTest.java
URL: http://svn.apache.org/viewvc/commons/proper/lang/trunk/src/test/org/apache/commons/lang3/builder/SimpleToStringStyleTest.java?rev=889215&r1=889214&r2=889215&view=diff
==============================================================================
--- commons/proper/lang/trunk/src/test/org/apache/commons/lang3/builder/SimpleToStringStyleTest.java (original)
+++ commons/proper/lang/trunk/src/test/org/apache/commons/lang3/builder/SimpleToStringStyleTest.java Thu Dec 10 11:56:38 2009
@@ -14,12 +14,12 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.lang.builder;
+package org.apache.commons.lang3.builder;
 
 import java.util.ArrayList;
 import java.util.HashMap;
 
-import org.apache.commons.lang.builder.ToStringStyleTest.Person;
+import org.apache.commons.lang3.builder.ToStringStyleTest.Person;
 
 import junit.framework.Test;
 import junit.framework.TestCase;

Modified: commons/proper/lang/trunk/src/test/org/apache/commons/lang3/builder/StandardToStringStyleTest.java
URL: http://svn.apache.org/viewvc/commons/proper/lang/trunk/src/test/org/apache/commons/lang3/builder/StandardToStringStyleTest.java?rev=889215&r1=889214&r2=889215&view=diff
==============================================================================
--- commons/proper/lang/trunk/src/test/org/apache/commons/lang3/builder/StandardToStringStyleTest.java (original)
+++ commons/proper/lang/trunk/src/test/org/apache/commons/lang3/builder/StandardToStringStyleTest.java Thu Dec 10 11:56:38 2009
@@ -14,12 +14,12 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.lang.builder;
+package org.apache.commons.lang3.builder;
 
 import java.util.ArrayList;
 import java.util.HashMap;
 
-import org.apache.commons.lang.builder.ToStringStyleTest.Person;
+import org.apache.commons.lang3.builder.ToStringStyleTest.Person;
 
 import junit.framework.Test;
 import junit.framework.TestCase;

Modified: commons/proper/lang/trunk/src/test/org/apache/commons/lang3/builder/ToStringBuilderTest.java
URL: http://svn.apache.org/viewvc/commons/proper/lang/trunk/src/test/org/apache/commons/lang3/builder/ToStringBuilderTest.java?rev=889215&r1=889214&r2=889215&view=diff
==============================================================================
--- commons/proper/lang/trunk/src/test/org/apache/commons/lang3/builder/ToStringBuilderTest.java (original)
+++ commons/proper/lang/trunk/src/test/org/apache/commons/lang3/builder/ToStringBuilderTest.java Thu Dec 10 11:56:38 2009
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.lang.builder;
+package org.apache.commons.lang3.builder;
 
 import java.util.ArrayList;
 import java.util.HashMap;

Modified: commons/proper/lang/trunk/src/test/org/apache/commons/lang3/builder/ToStringStyleTest.java
URL: http://svn.apache.org/viewvc/commons/proper/lang/trunk/src/test/org/apache/commons/lang3/builder/ToStringStyleTest.java?rev=889215&r1=889214&r2=889215&view=diff
==============================================================================
--- commons/proper/lang/trunk/src/test/org/apache/commons/lang3/builder/ToStringStyleTest.java (original)
+++ commons/proper/lang/trunk/src/test/org/apache/commons/lang3/builder/ToStringStyleTest.java Thu Dec 10 11:56:38 2009
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.lang.builder;
+package org.apache.commons.lang3.builder;
 
 import junit.framework.Test;
 import junit.framework.TestCase;

Modified: commons/proper/lang/trunk/src/test/org/apache/commons/lang3/concurrent/BackgroundInitializerTest.java
URL: http://svn.apache.org/viewvc/commons/proper/lang/trunk/src/test/org/apache/commons/lang3/concurrent/BackgroundInitializerTest.java?rev=889215&r1=889214&r2=889215&view=diff
==============================================================================
--- commons/proper/lang/trunk/src/test/org/apache/commons/lang3/concurrent/BackgroundInitializerTest.java (original)
+++ commons/proper/lang/trunk/src/test/org/apache/commons/lang3/concurrent/BackgroundInitializerTest.java Thu Dec 10 11:56:38 2009
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.lang.concurrent;
+package org.apache.commons.lang3.concurrent;
 
 import java.util.concurrent.CountDownLatch;
 import java.util.concurrent.ExecutorService;

Modified: commons/proper/lang/trunk/src/test/org/apache/commons/lang3/concurrent/CallableBackgroundInitializerTest.java
URL: http://svn.apache.org/viewvc/commons/proper/lang/trunk/src/test/org/apache/commons/lang3/concurrent/CallableBackgroundInitializerTest.java?rev=889215&r1=889214&r2=889215&view=diff
==============================================================================
--- commons/proper/lang/trunk/src/test/org/apache/commons/lang3/concurrent/CallableBackgroundInitializerTest.java (original)
+++ commons/proper/lang/trunk/src/test/org/apache/commons/lang3/concurrent/CallableBackgroundInitializerTest.java Thu Dec 10 11:56:38 2009
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.lang.concurrent;
+package org.apache.commons.lang3.concurrent;
 
 import java.util.concurrent.Callable;
 import java.util.concurrent.ExecutorService;

Modified: commons/proper/lang/trunk/src/test/org/apache/commons/lang3/concurrent/ConcurrentUtilsTest.java
URL: http://svn.apache.org/viewvc/commons/proper/lang/trunk/src/test/org/apache/commons/lang3/concurrent/ConcurrentUtilsTest.java?rev=889215&r1=889214&r2=889215&view=diff
==============================================================================
--- commons/proper/lang/trunk/src/test/org/apache/commons/lang3/concurrent/ConcurrentUtilsTest.java (original)
+++ commons/proper/lang/trunk/src/test/org/apache/commons/lang3/concurrent/ConcurrentUtilsTest.java Thu Dec 10 11:56:38 2009
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.lang.concurrent;
+package org.apache.commons.lang3.concurrent;
 
 import java.util.concurrent.ExecutionException;
 import java.util.concurrent.Future;

Modified: commons/proper/lang/trunk/src/test/org/apache/commons/lang3/concurrent/LazyInitializerTest.java
URL: http://svn.apache.org/viewvc/commons/proper/lang/trunk/src/test/org/apache/commons/lang3/concurrent/LazyInitializerTest.java?rev=889215&r1=889214&r2=889215&view=diff
==============================================================================
--- commons/proper/lang/trunk/src/test/org/apache/commons/lang3/concurrent/LazyInitializerTest.java (original)
+++ commons/proper/lang/trunk/src/test/org/apache/commons/lang3/concurrent/LazyInitializerTest.java Thu Dec 10 11:56:38 2009
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.lang.concurrent;
+package org.apache.commons.lang3.concurrent;
 
 import java.util.concurrent.CountDownLatch;
 

Modified: commons/proper/lang/trunk/src/test/org/apache/commons/lang3/concurrent/MultiBackgroundInitializerTest.java
URL: http://svn.apache.org/viewvc/commons/proper/lang/trunk/src/test/org/apache/commons/lang3/concurrent/MultiBackgroundInitializerTest.java?rev=889215&r1=889214&r2=889215&view=diff
==============================================================================
--- commons/proper/lang/trunk/src/test/org/apache/commons/lang3/concurrent/MultiBackgroundInitializerTest.java (original)
+++ commons/proper/lang/trunk/src/test/org/apache/commons/lang3/concurrent/MultiBackgroundInitializerTest.java Thu Dec 10 11:56:38 2009
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.lang.concurrent;
+package org.apache.commons.lang3.concurrent;
 
 import java.util.Iterator;
 import java.util.NoSuchElementException;

Modified: commons/proper/lang/trunk/src/test/org/apache/commons/lang3/exception/ContextedExceptionTest.java
URL: http://svn.apache.org/viewvc/commons/proper/lang/trunk/src/test/org/apache/commons/lang3/exception/ContextedExceptionTest.java?rev=889215&r1=889214&r2=889215&view=diff
==============================================================================
--- commons/proper/lang/trunk/src/test/org/apache/commons/lang3/exception/ContextedExceptionTest.java (original)
+++ commons/proper/lang/trunk/src/test/org/apache/commons/lang3/exception/ContextedExceptionTest.java Thu Dec 10 11:56:38 2009
@@ -14,14 +14,14 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.lang.exception;
+package org.apache.commons.lang3.exception;
 
 import java.io.Serializable;
 import java.util.Date;
 
 import junit.framework.TestCase;
 
-import org.apache.commons.lang.StringUtils;
+import org.apache.commons.lang3.StringUtils;
 
 /**
  * JUnit tests for ContextedException.

Modified: commons/proper/lang/trunk/src/test/org/apache/commons/lang3/exception/ContextedRuntimeExceptionTest.java
URL: http://svn.apache.org/viewvc/commons/proper/lang/trunk/src/test/org/apache/commons/lang3/exception/ContextedRuntimeExceptionTest.java?rev=889215&r1=889214&r2=889215&view=diff
==============================================================================
--- commons/proper/lang/trunk/src/test/org/apache/commons/lang3/exception/ContextedRuntimeExceptionTest.java (original)
+++ commons/proper/lang/trunk/src/test/org/apache/commons/lang3/exception/ContextedRuntimeExceptionTest.java Thu Dec 10 11:56:38 2009
@@ -14,14 +14,14 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.lang.exception;
+package org.apache.commons.lang3.exception;
 
 import java.util.Date;
 
 import junit.framework.TestCase;
 
-import org.apache.commons.lang.StringUtils;
-import org.apache.commons.lang.exception.ContextedExceptionTest.ObjectWithFaultyToString;
+import org.apache.commons.lang3.StringUtils;
+import org.apache.commons.lang3.exception.ContextedExceptionTest.ObjectWithFaultyToString;
 
 /**
  * JUnit tests for ContextedRuntimeException.

Modified: commons/proper/lang/trunk/src/test/org/apache/commons/lang3/exception/DefaultExceptionContextTest.java
URL: http://svn.apache.org/viewvc/commons/proper/lang/trunk/src/test/org/apache/commons/lang3/exception/DefaultExceptionContextTest.java?rev=889215&r1=889214&r2=889215&view=diff
==============================================================================
--- commons/proper/lang/trunk/src/test/org/apache/commons/lang3/exception/DefaultExceptionContextTest.java (original)
+++ commons/proper/lang/trunk/src/test/org/apache/commons/lang3/exception/DefaultExceptionContextTest.java Thu Dec 10 11:56:38 2009
@@ -14,11 +14,11 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.lang.exception;
+package org.apache.commons.lang3.exception;
 
 import java.util.Date;
 
-import org.apache.commons.lang.exception.ContextedExceptionTest.ObjectWithFaultyToString;
+import org.apache.commons.lang3.exception.ContextedExceptionTest.ObjectWithFaultyToString;
 
 import junit.framework.TestCase;
 

Modified: commons/proper/lang/trunk/src/test/org/apache/commons/lang3/exception/ExceptionUtilsTest.java
URL: http://svn.apache.org/viewvc/commons/proper/lang/trunk/src/test/org/apache/commons/lang3/exception/ExceptionUtilsTest.java?rev=889215&r1=889214&r2=889215&view=diff
==============================================================================
--- commons/proper/lang/trunk/src/test/org/apache/commons/lang3/exception/ExceptionUtilsTest.java (original)
+++ commons/proper/lang/trunk/src/test/org/apache/commons/lang3/exception/ExceptionUtilsTest.java Thu Dec 10 11:56:38 2009
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.lang.exception;
+package org.apache.commons.lang3.exception;
 
 import java.io.ByteArrayOutputStream;
 import java.io.IOException;
@@ -32,7 +32,7 @@
 import junit.framework.TestCase;
 import junit.framework.TestSuite;
 
-import org.apache.commons.lang.SystemUtils;
+import org.apache.commons.lang3.SystemUtils;
 
 /**
  * Tests {@link org.apache.commons.lang.exception.ExceptionUtils}.

Modified: commons/proper/lang/trunk/src/test/org/apache/commons/lang3/math/FractionTest.java
URL: http://svn.apache.org/viewvc/commons/proper/lang/trunk/src/test/org/apache/commons/lang3/math/FractionTest.java?rev=889215&r1=889214&r2=889215&view=diff
==============================================================================
--- commons/proper/lang/trunk/src/test/org/apache/commons/lang3/math/FractionTest.java (original)
+++ commons/proper/lang/trunk/src/test/org/apache/commons/lang3/math/FractionTest.java Thu Dec 10 11:56:38 2009
@@ -16,7 +16,7 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package org.apache.commons.lang.math;
+package org.apache.commons.lang3.math;
 
 import junit.framework.Test;
 import junit.framework.TestCase;

Modified: commons/proper/lang/trunk/src/test/org/apache/commons/lang3/math/IEEE754rUtilsTest.java
URL: http://svn.apache.org/viewvc/commons/proper/lang/trunk/src/test/org/apache/commons/lang3/math/IEEE754rUtilsTest.java?rev=889215&r1=889214&r2=889215&view=diff
==============================================================================
--- commons/proper/lang/trunk/src/test/org/apache/commons/lang3/math/IEEE754rUtilsTest.java (original)
+++ commons/proper/lang/trunk/src/test/org/apache/commons/lang3/math/IEEE754rUtilsTest.java Thu Dec 10 11:56:38 2009
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.lang.math;
+package org.apache.commons.lang3.math;
 
 import junit.framework.TestCase;
 

Modified: commons/proper/lang/trunk/src/test/org/apache/commons/lang3/math/NumberUtilsTest.java
URL: http://svn.apache.org/viewvc/commons/proper/lang/trunk/src/test/org/apache/commons/lang3/math/NumberUtilsTest.java?rev=889215&r1=889214&r2=889215&view=diff
==============================================================================
--- commons/proper/lang/trunk/src/test/org/apache/commons/lang3/math/NumberUtilsTest.java (original)
+++ commons/proper/lang/trunk/src/test/org/apache/commons/lang3/math/NumberUtilsTest.java Thu Dec 10 11:56:38 2009
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.lang.math;
+package org.apache.commons.lang3.math;
 
 import java.lang.reflect.Constructor;
 import java.lang.reflect.Modifier;
@@ -26,7 +26,7 @@
 import junit.framework.TestSuite;
 import junit.textui.TestRunner;
 
-import org.apache.commons.lang.SystemUtils;
+import org.apache.commons.lang3.SystemUtils;
 
 /**
  * Unit tests {@link org.apache.commons.lang.math.NumberUtils}.

Modified: commons/proper/lang/trunk/src/test/org/apache/commons/lang3/mutable/MutableBooleanTest.java
URL: http://svn.apache.org/viewvc/commons/proper/lang/trunk/src/test/org/apache/commons/lang3/mutable/MutableBooleanTest.java?rev=889215&r1=889214&r2=889215&view=diff
==============================================================================
--- commons/proper/lang/trunk/src/test/org/apache/commons/lang3/mutable/MutableBooleanTest.java (original)
+++ commons/proper/lang/trunk/src/test/org/apache/commons/lang3/mutable/MutableBooleanTest.java Thu Dec 10 11:56:38 2009
@@ -15,7 +15,7 @@
  * limitations under the License.
  */
 
-package org.apache.commons.lang.mutable;
+package org.apache.commons.lang3.mutable;
 
 import junit.framework.Test;
 import junit.framework.TestCase;

Modified: commons/proper/lang/trunk/src/test/org/apache/commons/lang3/mutable/MutableByteTest.java
URL: http://svn.apache.org/viewvc/commons/proper/lang/trunk/src/test/org/apache/commons/lang3/mutable/MutableByteTest.java?rev=889215&r1=889214&r2=889215&view=diff
==============================================================================
--- commons/proper/lang/trunk/src/test/org/apache/commons/lang3/mutable/MutableByteTest.java (original)
+++ commons/proper/lang/trunk/src/test/org/apache/commons/lang3/mutable/MutableByteTest.java Thu Dec 10 11:56:38 2009
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.lang.mutable;
+package org.apache.commons.lang3.mutable;
 
 import junit.framework.Test;
 import junit.framework.TestCase;

Modified: commons/proper/lang/trunk/src/test/org/apache/commons/lang3/mutable/MutableDoubleTest.java
URL: http://svn.apache.org/viewvc/commons/proper/lang/trunk/src/test/org/apache/commons/lang3/mutable/MutableDoubleTest.java?rev=889215&r1=889214&r2=889215&view=diff
==============================================================================
--- commons/proper/lang/trunk/src/test/org/apache/commons/lang3/mutable/MutableDoubleTest.java (original)
+++ commons/proper/lang/trunk/src/test/org/apache/commons/lang3/mutable/MutableDoubleTest.java Thu Dec 10 11:56:38 2009
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.lang.mutable;
+package org.apache.commons.lang3.mutable;
 
 import junit.framework.Test;
 import junit.framework.TestCase;

Modified: commons/proper/lang/trunk/src/test/org/apache/commons/lang3/mutable/MutableFloatTest.java
URL: http://svn.apache.org/viewvc/commons/proper/lang/trunk/src/test/org/apache/commons/lang3/mutable/MutableFloatTest.java?rev=889215&r1=889214&r2=889215&view=diff
==============================================================================
--- commons/proper/lang/trunk/src/test/org/apache/commons/lang3/mutable/MutableFloatTest.java (original)
+++ commons/proper/lang/trunk/src/test/org/apache/commons/lang3/mutable/MutableFloatTest.java Thu Dec 10 11:56:38 2009
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.lang.mutable;
+package org.apache.commons.lang3.mutable;
 
 import junit.framework.Test;
 import junit.framework.TestCase;

Modified: commons/proper/lang/trunk/src/test/org/apache/commons/lang3/mutable/MutableIntTest.java
URL: http://svn.apache.org/viewvc/commons/proper/lang/trunk/src/test/org/apache/commons/lang3/mutable/MutableIntTest.java?rev=889215&r1=889214&r2=889215&view=diff
==============================================================================
--- commons/proper/lang/trunk/src/test/org/apache/commons/lang3/mutable/MutableIntTest.java (original)
+++ commons/proper/lang/trunk/src/test/org/apache/commons/lang3/mutable/MutableIntTest.java Thu Dec 10 11:56:38 2009
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.lang.mutable;
+package org.apache.commons.lang3.mutable;
 
 import junit.framework.Test;
 import junit.framework.TestCase;

Modified: commons/proper/lang/trunk/src/test/org/apache/commons/lang3/mutable/MutableLongTest.java
URL: http://svn.apache.org/viewvc/commons/proper/lang/trunk/src/test/org/apache/commons/lang3/mutable/MutableLongTest.java?rev=889215&r1=889214&r2=889215&view=diff
==============================================================================
--- commons/proper/lang/trunk/src/test/org/apache/commons/lang3/mutable/MutableLongTest.java (original)
+++ commons/proper/lang/trunk/src/test/org/apache/commons/lang3/mutable/MutableLongTest.java Thu Dec 10 11:56:38 2009
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.lang.mutable;
+package org.apache.commons.lang3.mutable;
 
 import junit.framework.Test;
 import junit.framework.TestCase;

Modified: commons/proper/lang/trunk/src/test/org/apache/commons/lang3/mutable/MutableObjectTest.java
URL: http://svn.apache.org/viewvc/commons/proper/lang/trunk/src/test/org/apache/commons/lang3/mutable/MutableObjectTest.java?rev=889215&r1=889214&r2=889215&view=diff
==============================================================================
--- commons/proper/lang/trunk/src/test/org/apache/commons/lang3/mutable/MutableObjectTest.java (original)
+++ commons/proper/lang/trunk/src/test/org/apache/commons/lang3/mutable/MutableObjectTest.java Thu Dec 10 11:56:38 2009
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.lang.mutable;
+package org.apache.commons.lang3.mutable;
 
 import junit.framework.Test;
 import junit.framework.TestCase;

Modified: commons/proper/lang/trunk/src/test/org/apache/commons/lang3/mutable/MutableShortTest.java
URL: http://svn.apache.org/viewvc/commons/proper/lang/trunk/src/test/org/apache/commons/lang3/mutable/MutableShortTest.java?rev=889215&r1=889214&r2=889215&view=diff
==============================================================================
--- commons/proper/lang/trunk/src/test/org/apache/commons/lang3/mutable/MutableShortTest.java (original)
+++ commons/proper/lang/trunk/src/test/org/apache/commons/lang3/mutable/MutableShortTest.java Thu Dec 10 11:56:38 2009
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.lang.mutable;
+package org.apache.commons.lang3.mutable;
 
 import junit.framework.Test;
 import junit.framework.TestCase;

Modified: commons/proper/lang/trunk/src/test/org/apache/commons/lang3/reflect/ConstructorUtilsTest.java
URL: http://svn.apache.org/viewvc/commons/proper/lang/trunk/src/test/org/apache/commons/lang3/reflect/ConstructorUtilsTest.java?rev=889215&r1=889214&r2=889215&view=diff
==============================================================================
--- commons/proper/lang/trunk/src/test/org/apache/commons/lang3/reflect/ConstructorUtilsTest.java (original)
+++ commons/proper/lang/trunk/src/test/org/apache/commons/lang3/reflect/ConstructorUtilsTest.java Thu Dec 10 11:56:38 2009
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.lang.reflect;
+package org.apache.commons.lang3.reflect;
 
 import java.lang.reflect.Constructor;
 import java.util.Arrays;
@@ -25,8 +25,8 @@
 import junit.framework.TestCase;
 import junit.framework.TestSuite;
 
-import org.apache.commons.lang.ArrayUtils;
-import org.apache.commons.lang.math.NumberUtils;
+import org.apache.commons.lang3.ArrayUtils;
+import org.apache.commons.lang3.math.NumberUtils;
 
 /**
  * Unit tests ConstructorUtils

Modified: commons/proper/lang/trunk/src/test/org/apache/commons/lang3/reflect/FieldUtilsTest.java
URL: http://svn.apache.org/viewvc/commons/proper/lang/trunk/src/test/org/apache/commons/lang3/reflect/FieldUtilsTest.java?rev=889215&r1=889214&r2=889215&view=diff
==============================================================================
--- commons/proper/lang/trunk/src/test/org/apache/commons/lang3/reflect/FieldUtilsTest.java (original)
+++ commons/proper/lang/trunk/src/test/org/apache/commons/lang3/reflect/FieldUtilsTest.java Thu Dec 10 11:56:38 2009
@@ -14,17 +14,17 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.lang.reflect;
+package org.apache.commons.lang3.reflect;
 
 import java.lang.reflect.Field;
 
-import org.apache.commons.lang.reflect.testbed.Ambig;
-import org.apache.commons.lang.reflect.testbed.Foo;
-import org.apache.commons.lang.reflect.testbed.PrivatelyShadowedChild;
-import org.apache.commons.lang.reflect.testbed.PublicChild;
-import org.apache.commons.lang.reflect.testbed.PubliclyShadowedChild;
-import org.apache.commons.lang.reflect.testbed.StaticContainer;
-import org.apache.commons.lang.reflect.testbed.StaticContainerChild;
+import org.apache.commons.lang3.reflect.testbed.Ambig;
+import org.apache.commons.lang3.reflect.testbed.Foo;
+import org.apache.commons.lang3.reflect.testbed.PrivatelyShadowedChild;
+import org.apache.commons.lang3.reflect.testbed.PublicChild;
+import org.apache.commons.lang3.reflect.testbed.PubliclyShadowedChild;
+import org.apache.commons.lang3.reflect.testbed.StaticContainer;
+import org.apache.commons.lang3.reflect.testbed.StaticContainerChild;
 
 import junit.framework.Test;
 import junit.framework.TestCase;

Modified: commons/proper/lang/trunk/src/test/org/apache/commons/lang3/reflect/MethodUtilsTest.java
URL: http://svn.apache.org/viewvc/commons/proper/lang/trunk/src/test/org/apache/commons/lang3/reflect/MethodUtilsTest.java?rev=889215&r1=889214&r2=889215&view=diff
==============================================================================
--- commons/proper/lang/trunk/src/test/org/apache/commons/lang3/reflect/MethodUtilsTest.java (original)
+++ commons/proper/lang/trunk/src/test/org/apache/commons/lang3/reflect/MethodUtilsTest.java Thu Dec 10 11:56:38 2009
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.lang.reflect;
+package org.apache.commons.lang3.reflect;
 
 import java.lang.reflect.Method;
 import java.util.Arrays;
@@ -25,10 +25,10 @@
 import junit.framework.TestCase;
 import junit.framework.TestSuite;
 
-import org.apache.commons.lang.ArrayUtils;
-import org.apache.commons.lang.math.NumberUtils;
-import org.apache.commons.lang.mutable.Mutable;
-import org.apache.commons.lang.mutable.MutableObject;
+import org.apache.commons.lang3.ArrayUtils;
+import org.apache.commons.lang3.math.NumberUtils;
+import org.apache.commons.lang3.mutable.Mutable;
+import org.apache.commons.lang3.mutable.MutableObject;
 
 /**
  * Unit tests MethodUtils

Modified: commons/proper/lang/trunk/src/test/org/apache/commons/lang3/reflect/TypeUtilsTest.java
URL: http://svn.apache.org/viewvc/commons/proper/lang/trunk/src/test/org/apache/commons/lang3/reflect/TypeUtilsTest.java?rev=889215&r1=889214&r2=889215&view=diff
==============================================================================
--- commons/proper/lang/trunk/src/test/org/apache/commons/lang3/reflect/TypeUtilsTest.java (original)
+++ commons/proper/lang/trunk/src/test/org/apache/commons/lang3/reflect/TypeUtilsTest.java Thu Dec 10 11:56:38 2009
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.lang.reflect;
+package org.apache.commons.lang3.reflect;
 
 import static junit.framework.Assert.*;
 
@@ -22,7 +22,7 @@
 import java.lang.reflect.TypeVariable;
 import java.util.List;
 
-import org.apache.commons.lang.reflect.testbed.*;
+import org.apache.commons.lang3.reflect.testbed.*;
 import org.junit.Before;
 import org.junit.Test;
 

Modified: commons/proper/lang/trunk/src/test/org/apache/commons/lang3/reflect/testbed/Ambig.java
URL: http://svn.apache.org/viewvc/commons/proper/lang/trunk/src/test/org/apache/commons/lang3/reflect/testbed/Ambig.java?rev=889215&r1=889214&r2=889215&view=diff
==============================================================================
--- commons/proper/lang/trunk/src/test/org/apache/commons/lang3/reflect/testbed/Ambig.java (original)
+++ commons/proper/lang/trunk/src/test/org/apache/commons/lang3/reflect/testbed/Ambig.java Thu Dec 10 11:56:38 2009
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.lang.reflect.testbed;
+package org.apache.commons.lang3.reflect.testbed;
 
 /**
  * @author mbenson

Modified: commons/proper/lang/trunk/src/test/org/apache/commons/lang3/reflect/testbed/Bar.java
URL: http://svn.apache.org/viewvc/commons/proper/lang/trunk/src/test/org/apache/commons/lang3/reflect/testbed/Bar.java?rev=889215&r1=889214&r2=889215&view=diff
==============================================================================
--- commons/proper/lang/trunk/src/test/org/apache/commons/lang3/reflect/testbed/Bar.java (original)
+++ commons/proper/lang/trunk/src/test/org/apache/commons/lang3/reflect/testbed/Bar.java Thu Dec 10 11:56:38 2009
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.lang.reflect.testbed;
+package org.apache.commons.lang3.reflect.testbed;
 
 /**
  * @author mbenson

Modified: commons/proper/lang/trunk/src/test/org/apache/commons/lang3/reflect/testbed/Foo.java
URL: http://svn.apache.org/viewvc/commons/proper/lang/trunk/src/test/org/apache/commons/lang3/reflect/testbed/Foo.java?rev=889215&r1=889214&r2=889215&view=diff
==============================================================================
--- commons/proper/lang/trunk/src/test/org/apache/commons/lang3/reflect/testbed/Foo.java (original)
+++ commons/proper/lang/trunk/src/test/org/apache/commons/lang3/reflect/testbed/Foo.java Thu Dec 10 11:56:38 2009
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.lang.reflect.testbed;
+package org.apache.commons.lang3.reflect.testbed;
 
 /**
  * @author mbenson

Modified: commons/proper/lang/trunk/src/test/org/apache/commons/lang3/reflect/testbed/GenericParent.java
URL: http://svn.apache.org/viewvc/commons/proper/lang/trunk/src/test/org/apache/commons/lang3/reflect/testbed/GenericParent.java?rev=889215&r1=889214&r2=889215&view=diff
==============================================================================
--- commons/proper/lang/trunk/src/test/org/apache/commons/lang3/reflect/testbed/GenericParent.java (original)
+++ commons/proper/lang/trunk/src/test/org/apache/commons/lang3/reflect/testbed/GenericParent.java Thu Dec 10 11:56:38 2009
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.lang.reflect.testbed;
+package org.apache.commons.lang3.reflect.testbed;
 
 /**
  * Class declaring a parameter variable.

Modified: commons/proper/lang/trunk/src/test/org/apache/commons/lang3/reflect/testbed/GenericTypeHolder.java
URL: http://svn.apache.org/viewvc/commons/proper/lang/trunk/src/test/org/apache/commons/lang3/reflect/testbed/GenericTypeHolder.java?rev=889215&r1=889214&r2=889215&view=diff
==============================================================================
--- commons/proper/lang/trunk/src/test/org/apache/commons/lang3/reflect/testbed/GenericTypeHolder.java (original)
+++ commons/proper/lang/trunk/src/test/org/apache/commons/lang3/reflect/testbed/GenericTypeHolder.java Thu Dec 10 11:56:38 2009
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.lang.reflect.testbed;
+package org.apache.commons.lang3.reflect.testbed;
 
 import java.util.List;
 

Modified: commons/proper/lang/trunk/src/test/org/apache/commons/lang3/reflect/testbed/Parent.java
URL: http://svn.apache.org/viewvc/commons/proper/lang/trunk/src/test/org/apache/commons/lang3/reflect/testbed/Parent.java?rev=889215&r1=889214&r2=889215&view=diff
==============================================================================
--- commons/proper/lang/trunk/src/test/org/apache/commons/lang3/reflect/testbed/Parent.java (original)
+++ commons/proper/lang/trunk/src/test/org/apache/commons/lang3/reflect/testbed/Parent.java Thu Dec 10 11:56:38 2009
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.lang.reflect.testbed;
+package org.apache.commons.lang3.reflect.testbed;
 
 /**
  * @author mbenson

Modified: commons/proper/lang/trunk/src/test/org/apache/commons/lang3/reflect/testbed/PrivatelyShadowedChild.java
URL: http://svn.apache.org/viewvc/commons/proper/lang/trunk/src/test/org/apache/commons/lang3/reflect/testbed/PrivatelyShadowedChild.java?rev=889215&r1=889214&r2=889215&view=diff
==============================================================================
--- commons/proper/lang/trunk/src/test/org/apache/commons/lang3/reflect/testbed/PrivatelyShadowedChild.java (original)
+++ commons/proper/lang/trunk/src/test/org/apache/commons/lang3/reflect/testbed/PrivatelyShadowedChild.java Thu Dec 10 11:56:38 2009
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.lang.reflect.testbed;
+package org.apache.commons.lang3.reflect.testbed;
 
 /**
  * @author mbenson

Modified: commons/proper/lang/trunk/src/test/org/apache/commons/lang3/reflect/testbed/PublicChild.java
URL: http://svn.apache.org/viewvc/commons/proper/lang/trunk/src/test/org/apache/commons/lang3/reflect/testbed/PublicChild.java?rev=889215&r1=889214&r2=889215&view=diff
==============================================================================
--- commons/proper/lang/trunk/src/test/org/apache/commons/lang3/reflect/testbed/PublicChild.java (original)
+++ commons/proper/lang/trunk/src/test/org/apache/commons/lang3/reflect/testbed/PublicChild.java Thu Dec 10 11:56:38 2009
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.lang.reflect.testbed;
+package org.apache.commons.lang3.reflect.testbed;
 
 /**
  * @author mbenson

Modified: commons/proper/lang/trunk/src/test/org/apache/commons/lang3/reflect/testbed/PubliclyShadowedChild.java
URL: http://svn.apache.org/viewvc/commons/proper/lang/trunk/src/test/org/apache/commons/lang3/reflect/testbed/PubliclyShadowedChild.java?rev=889215&r1=889214&r2=889215&view=diff
==============================================================================
--- commons/proper/lang/trunk/src/test/org/apache/commons/lang3/reflect/testbed/PubliclyShadowedChild.java (original)
+++ commons/proper/lang/trunk/src/test/org/apache/commons/lang3/reflect/testbed/PubliclyShadowedChild.java Thu Dec 10 11:56:38 2009
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.lang.reflect.testbed;
+package org.apache.commons.lang3.reflect.testbed;
 
 /**
  * @author mbenson

Modified: commons/proper/lang/trunk/src/test/org/apache/commons/lang3/reflect/testbed/StaticContainer.java
URL: http://svn.apache.org/viewvc/commons/proper/lang/trunk/src/test/org/apache/commons/lang3/reflect/testbed/StaticContainer.java?rev=889215&r1=889214&r2=889215&view=diff
==============================================================================
--- commons/proper/lang/trunk/src/test/org/apache/commons/lang3/reflect/testbed/StaticContainer.java (original)
+++ commons/proper/lang/trunk/src/test/org/apache/commons/lang3/reflect/testbed/StaticContainer.java Thu Dec 10 11:56:38 2009
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.lang.reflect.testbed;
+package org.apache.commons.lang3.reflect.testbed;
 
 /**
  * @author mbenson

Modified: commons/proper/lang/trunk/src/test/org/apache/commons/lang3/reflect/testbed/StaticContainerChild.java
URL: http://svn.apache.org/viewvc/commons/proper/lang/trunk/src/test/org/apache/commons/lang3/reflect/testbed/StaticContainerChild.java?rev=889215&r1=889214&r2=889215&view=diff
==============================================================================
--- commons/proper/lang/trunk/src/test/org/apache/commons/lang3/reflect/testbed/StaticContainerChild.java (original)
+++ commons/proper/lang/trunk/src/test/org/apache/commons/lang3/reflect/testbed/StaticContainerChild.java Thu Dec 10 11:56:38 2009
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.lang.reflect.testbed;
+package org.apache.commons.lang3.reflect.testbed;
 
 /**
  * @author mbenson

Modified: commons/proper/lang/trunk/src/test/org/apache/commons/lang3/reflect/testbed/StringParameterizedChild.java
URL: http://svn.apache.org/viewvc/commons/proper/lang/trunk/src/test/org/apache/commons/lang3/reflect/testbed/StringParameterizedChild.java?rev=889215&r1=889214&r2=889215&view=diff
==============================================================================
--- commons/proper/lang/trunk/src/test/org/apache/commons/lang3/reflect/testbed/StringParameterizedChild.java (original)
+++ commons/proper/lang/trunk/src/test/org/apache/commons/lang3/reflect/testbed/StringParameterizedChild.java Thu Dec 10 11:56:38 2009
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.lang.reflect.testbed;
+package org.apache.commons.lang3.reflect.testbed;
 
 /**
  * {@link GenericParent} subclass that explicitly specifies <T> as {@link String}.

Modified: commons/proper/lang/trunk/src/test/org/apache/commons/lang3/text/CompositeFormatTest.java
URL: http://svn.apache.org/viewvc/commons/proper/lang/trunk/src/test/org/apache/commons/lang3/text/CompositeFormatTest.java?rev=889215&r1=889214&r2=889215&view=diff
==============================================================================
--- commons/proper/lang/trunk/src/test/org/apache/commons/lang3/text/CompositeFormatTest.java (original)
+++ commons/proper/lang/trunk/src/test/org/apache/commons/lang3/text/CompositeFormatTest.java Thu Dec 10 11:56:38 2009
@@ -15,7 +15,7 @@
  * limitations under the License.
  */
 
-package org.apache.commons.lang.text;
+package org.apache.commons.lang3.text;
 
 import java.text.FieldPosition;
 import java.text.Format;

Modified: commons/proper/lang/trunk/src/test/org/apache/commons/lang3/text/ExtendedMessageFormatTest.java
URL: http://svn.apache.org/viewvc/commons/proper/lang/trunk/src/test/org/apache/commons/lang3/text/ExtendedMessageFormatTest.java?rev=889215&r1=889214&r2=889215&view=diff
==============================================================================
--- commons/proper/lang/trunk/src/test/org/apache/commons/lang3/text/ExtendedMessageFormatTest.java (original)
+++ commons/proper/lang/trunk/src/test/org/apache/commons/lang3/text/ExtendedMessageFormatTest.java Thu Dec 10 11:56:38 2009
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.lang.text;
+package org.apache.commons.lang3.text;
 
 import java.text.ChoiceFormat;
 import java.text.DateFormat;
@@ -32,7 +32,7 @@
 import java.util.Locale;
 import java.util.Map;
 
-import org.apache.commons.lang.SystemUtils;
+import org.apache.commons.lang3.SystemUtils;
 
 import junit.framework.Test;
 import junit.framework.TestCase;

Modified: commons/proper/lang/trunk/src/test/org/apache/commons/lang3/text/StrBuilderAppendInsertTest.java
URL: http://svn.apache.org/viewvc/commons/proper/lang/trunk/src/test/org/apache/commons/lang3/text/StrBuilderAppendInsertTest.java?rev=889215&r1=889214&r2=889215&view=diff
==============================================================================
--- commons/proper/lang/trunk/src/test/org/apache/commons/lang3/text/StrBuilderAppendInsertTest.java (original)
+++ commons/proper/lang/trunk/src/test/org/apache/commons/lang3/text/StrBuilderAppendInsertTest.java Thu Dec 10 11:56:38 2009
@@ -15,7 +15,7 @@
  * limitations under the License.
  */
 
-package org.apache.commons.lang.text;
+package org.apache.commons.lang3.text;
 
 import java.util.Arrays;
 import java.util.Collection;
@@ -27,7 +27,7 @@
 import junit.framework.TestSuite;
 import junit.textui.TestRunner;
 
-import org.apache.commons.lang.SystemUtils;
+import org.apache.commons.lang3.SystemUtils;
 
 /**
  * Unit tests for {@link org.apache.commons.lang.text.StrBuilder}.

Modified: commons/proper/lang/trunk/src/test/org/apache/commons/lang3/text/StrBuilderTest.java
URL: http://svn.apache.org/viewvc/commons/proper/lang/trunk/src/test/org/apache/commons/lang3/text/StrBuilderTest.java?rev=889215&r1=889214&r2=889215&view=diff
==============================================================================
--- commons/proper/lang/trunk/src/test/org/apache/commons/lang3/text/StrBuilderTest.java (original)
+++ commons/proper/lang/trunk/src/test/org/apache/commons/lang3/text/StrBuilderTest.java Thu Dec 10 11:56:38 2009
@@ -15,7 +15,7 @@
  * limitations under the License.
  */
 
-package org.apache.commons.lang.text;
+package org.apache.commons.lang3.text;
 
 import java.io.Reader;
 import java.io.Writer;
@@ -26,7 +26,7 @@
 import junit.framework.TestSuite;
 import junit.textui.TestRunner;
 
-import org.apache.commons.lang.ArrayUtils;
+import org.apache.commons.lang3.ArrayUtils;
 
 /**
  * Unit tests for {@link org.apache.commons.lang.text.StrBuilder}.

Modified: commons/proper/lang/trunk/src/test/org/apache/commons/lang3/text/StrLookupTest.java
URL: http://svn.apache.org/viewvc/commons/proper/lang/trunk/src/test/org/apache/commons/lang3/text/StrLookupTest.java?rev=889215&r1=889214&r2=889215&view=diff
==============================================================================
--- commons/proper/lang/trunk/src/test/org/apache/commons/lang3/text/StrLookupTest.java (original)
+++ commons/proper/lang/trunk/src/test/org/apache/commons/lang3/text/StrLookupTest.java Thu Dec 10 11:56:38 2009
@@ -15,7 +15,7 @@
  * limitations under the License.
  */
 
-package org.apache.commons.lang.text;
+package org.apache.commons.lang3.text;
 
 import java.util.HashMap;
 import java.util.Map;

Modified: commons/proper/lang/trunk/src/test/org/apache/commons/lang3/text/StrMatcherTest.java
URL: http://svn.apache.org/viewvc/commons/proper/lang/trunk/src/test/org/apache/commons/lang3/text/StrMatcherTest.java?rev=889215&r1=889214&r2=889215&view=diff
==============================================================================
--- commons/proper/lang/trunk/src/test/org/apache/commons/lang3/text/StrMatcherTest.java (original)
+++ commons/proper/lang/trunk/src/test/org/apache/commons/lang3/text/StrMatcherTest.java Thu Dec 10 11:56:38 2009
@@ -15,7 +15,7 @@
  * limitations under the License.
  */
 
-package org.apache.commons.lang.text;
+package org.apache.commons.lang3.text;
 
 import junit.framework.Test;
 import junit.framework.TestCase;

Modified: commons/proper/lang/trunk/src/test/org/apache/commons/lang3/text/StrSubstitutorTest.java
URL: http://svn.apache.org/viewvc/commons/proper/lang/trunk/src/test/org/apache/commons/lang3/text/StrSubstitutorTest.java?rev=889215&r1=889214&r2=889215&view=diff
==============================================================================
--- commons/proper/lang/trunk/src/test/org/apache/commons/lang3/text/StrSubstitutorTest.java (original)
+++ commons/proper/lang/trunk/src/test/org/apache/commons/lang3/text/StrSubstitutorTest.java Thu Dec 10 11:56:38 2009
@@ -15,7 +15,7 @@
  * limitations under the License.
  */
 
-package org.apache.commons.lang.text;
+package org.apache.commons.lang3.text;
 
 import java.util.HashMap;
 import java.util.Map;
@@ -25,7 +25,7 @@
 import junit.framework.TestSuite;
 import junit.textui.TestRunner;
 
-import org.apache.commons.lang.mutable.MutableObject;
+import org.apache.commons.lang3.mutable.MutableObject;
 
 /**
  * Test class for StrSubstitutor.

Modified: commons/proper/lang/trunk/src/test/org/apache/commons/lang3/text/StrTokenizerTest.java
URL: http://svn.apache.org/viewvc/commons/proper/lang/trunk/src/test/org/apache/commons/lang3/text/StrTokenizerTest.java?rev=889215&r1=889214&r2=889215&view=diff
==============================================================================
--- commons/proper/lang/trunk/src/test/org/apache/commons/lang3/text/StrTokenizerTest.java (original)
+++ commons/proper/lang/trunk/src/test/org/apache/commons/lang3/text/StrTokenizerTest.java Thu Dec 10 11:56:38 2009
@@ -15,7 +15,7 @@
  * limitations under the License.
  */
 
-package org.apache.commons.lang.text;
+package org.apache.commons.lang3.text;
 
 import java.util.Arrays;
 import java.util.Collections;
@@ -27,8 +27,8 @@
 import junit.framework.TestSuite;
 import junit.textui.TestRunner;
 
-import org.apache.commons.lang.ArrayUtils;
-import org.apache.commons.lang.ObjectUtils;
+import org.apache.commons.lang3.ArrayUtils;
+import org.apache.commons.lang3.ObjectUtils;
 
 /**
  * Unit test for Tokenizer.

Modified: commons/proper/lang/trunk/src/test/org/apache/commons/lang3/text/translate/EntityArraysTest.java
URL: http://svn.apache.org/viewvc/commons/proper/lang/trunk/src/test/org/apache/commons/lang3/text/translate/EntityArraysTest.java?rev=889215&r1=889214&r2=889215&view=diff
==============================================================================
--- commons/proper/lang/trunk/src/test/org/apache/commons/lang3/text/translate/EntityArraysTest.java (original)
+++ commons/proper/lang/trunk/src/test/org/apache/commons/lang3/text/translate/EntityArraysTest.java Thu Dec 10 11:56:38 2009
@@ -15,7 +15,7 @@
  * limitations under the License.
  */
 
-package org.apache.commons.lang.text.translate;
+package org.apache.commons.lang3.text.translate;
 
 import junit.framework.TestCase;
 

Modified: commons/proper/lang/trunk/src/test/org/apache/commons/lang3/text/translate/LookupTranslatorTest.java
URL: http://svn.apache.org/viewvc/commons/proper/lang/trunk/src/test/org/apache/commons/lang3/text/translate/LookupTranslatorTest.java?rev=889215&r1=889214&r2=889215&view=diff
==============================================================================
--- commons/proper/lang/trunk/src/test/org/apache/commons/lang3/text/translate/LookupTranslatorTest.java (original)
+++ commons/proper/lang/trunk/src/test/org/apache/commons/lang3/text/translate/LookupTranslatorTest.java Thu Dec 10 11:56:38 2009
@@ -15,7 +15,7 @@
  * limitations under the License.
  */
 
-package org.apache.commons.lang.text.translate;
+package org.apache.commons.lang3.text.translate;
 
 import junit.framework.TestCase;
 

Modified: commons/proper/lang/trunk/src/test/org/apache/commons/lang3/text/translate/NumericEntityEscaperTest.java
URL: http://svn.apache.org/viewvc/commons/proper/lang/trunk/src/test/org/apache/commons/lang3/text/translate/NumericEntityEscaperTest.java?rev=889215&r1=889214&r2=889215&view=diff
==============================================================================
--- commons/proper/lang/trunk/src/test/org/apache/commons/lang3/text/translate/NumericEntityEscaperTest.java (original)
+++ commons/proper/lang/trunk/src/test/org/apache/commons/lang3/text/translate/NumericEntityEscaperTest.java Thu Dec 10 11:56:38 2009
@@ -15,7 +15,7 @@
  * limitations under the License.
  */
 
-package org.apache.commons.lang.text.translate;
+package org.apache.commons.lang3.text.translate;
 
 import junit.framework.TestCase;
 

Modified: commons/proper/lang/trunk/src/test/org/apache/commons/lang3/text/translate/UnicodeEscaperTest.java
URL: http://svn.apache.org/viewvc/commons/proper/lang/trunk/src/test/org/apache/commons/lang3/text/translate/UnicodeEscaperTest.java?rev=889215&r1=889214&r2=889215&view=diff
==============================================================================
--- commons/proper/lang/trunk/src/test/org/apache/commons/lang3/text/translate/UnicodeEscaperTest.java (original)
+++ commons/proper/lang/trunk/src/test/org/apache/commons/lang3/text/translate/UnicodeEscaperTest.java Thu Dec 10 11:56:38 2009
@@ -15,7 +15,7 @@
  * limitations under the License.
  */
 
-package org.apache.commons.lang.text.translate;
+package org.apache.commons.lang3.text.translate;
 
 import junit.framework.TestCase;
 

Modified: commons/proper/lang/trunk/src/test/org/apache/commons/lang3/text/translate/UnicodeUnescaperTest.java
URL: http://svn.apache.org/viewvc/commons/proper/lang/trunk/src/test/org/apache/commons/lang3/text/translate/UnicodeUnescaperTest.java?rev=889215&r1=889214&r2=889215&view=diff
==============================================================================
--- commons/proper/lang/trunk/src/test/org/apache/commons/lang3/text/translate/UnicodeUnescaperTest.java (original)
+++ commons/proper/lang/trunk/src/test/org/apache/commons/lang3/text/translate/UnicodeUnescaperTest.java Thu Dec 10 11:56:38 2009
@@ -15,7 +15,7 @@
  * limitations under the License.
  */
 
-package org.apache.commons.lang.text.translate;
+package org.apache.commons.lang3.text.translate;
 
 import junit.framework.TestCase;
 

Modified: commons/proper/lang/trunk/src/test/org/apache/commons/lang3/time/DateFormatUtilsTest.java
URL: http://svn.apache.org/viewvc/commons/proper/lang/trunk/src/test/org/apache/commons/lang3/time/DateFormatUtilsTest.java?rev=889215&r1=889214&r2=889215&view=diff
==============================================================================
--- commons/proper/lang/trunk/src/test/org/apache/commons/lang3/time/DateFormatUtilsTest.java (original)
+++ commons/proper/lang/trunk/src/test/org/apache/commons/lang3/time/DateFormatUtilsTest.java Thu Dec 10 11:56:38 2009
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.lang.time;
+package org.apache.commons.lang3.time;
 
 import java.lang.reflect.Constructor;
 import java.lang.reflect.Modifier;

Modified: commons/proper/lang/trunk/src/test/org/apache/commons/lang3/time/DateUtilsFragmentTest.java
URL: http://svn.apache.org/viewvc/commons/proper/lang/trunk/src/test/org/apache/commons/lang3/time/DateUtilsFragmentTest.java?rev=889215&r1=889214&r2=889215&view=diff
==============================================================================
--- commons/proper/lang/trunk/src/test/org/apache/commons/lang3/time/DateUtilsFragmentTest.java (original)
+++ commons/proper/lang/trunk/src/test/org/apache/commons/lang3/time/DateUtilsFragmentTest.java Thu Dec 10 11:56:38 2009
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.lang.time;
+package org.apache.commons.lang3.time;
 
 import java.util.Calendar;
 import java.util.Date;

Modified: commons/proper/lang/trunk/src/test/org/apache/commons/lang3/time/DateUtilsRoundingTest.java
URL: http://svn.apache.org/viewvc/commons/proper/lang/trunk/src/test/org/apache/commons/lang3/time/DateUtilsRoundingTest.java?rev=889215&r1=889214&r2=889215&view=diff
==============================================================================
--- commons/proper/lang/trunk/src/test/org/apache/commons/lang3/time/DateUtilsRoundingTest.java (original)
+++ commons/proper/lang/trunk/src/test/org/apache/commons/lang3/time/DateUtilsRoundingTest.java Thu Dec 10 11:56:38 2009
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.lang.time;
+package org.apache.commons.lang3.time;
 
 import java.text.DateFormat;
 import java.text.SimpleDateFormat;

Modified: commons/proper/lang/trunk/src/test/org/apache/commons/lang3/time/DateUtilsTest.java
URL: http://svn.apache.org/viewvc/commons/proper/lang/trunk/src/test/org/apache/commons/lang3/time/DateUtilsTest.java?rev=889215&r1=889214&r2=889215&view=diff
==============================================================================
--- commons/proper/lang/trunk/src/test/org/apache/commons/lang3/time/DateUtilsTest.java (original)
+++ commons/proper/lang/trunk/src/test/org/apache/commons/lang3/time/DateUtilsTest.java Thu Dec 10 11:56:38 2009
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.lang.time;
+package org.apache.commons.lang3.time;
 
 import java.lang.reflect.Constructor;
 import java.lang.reflect.Modifier;
@@ -35,7 +35,7 @@
 import junit.framework.TestSuite;
 import junit.textui.TestRunner;
 
-import org.apache.commons.lang.SystemUtils;
+import org.apache.commons.lang3.SystemUtils;
 
 /**
  * Unit tests {@link org.apache.commons.lang.time.DateUtils}.
--- commons/proper/lang/trunk/src/test/org/apache/commons/lang3/ClassUtilsTest.java (original)
+++ commons/proper/lang/trunk/src/test/org/apache/commons/lang3/ClassUtilsTest.java Thu Dec 10 11:56:38 2009
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.lang;
+package org.apache.commons.lang3;
 
 import java.lang.reflect.Constructor;
 import java.lang.reflect.Method;
@@ -34,7 +34,7 @@
 
 
 /**
  * Unit tests {@link org.apache.commons.lang.ClassUtils}.
  *
  * @author Apache Software Foundation
  * @author Gary D. Gregory
@@ -132,8 +132,8 @@
 
     // -------------------------------------------------------------------------
     public void test_getPackageName_Object() {
-        assertEquals("org.apache.commons.lang", ClassUtils.getPackageName(new ClassUtils(), "<null>"));
-        assertEquals("org.apache.commons.lang", ClassUtils.getPackageName(new Inner(), "<null>"));
+        assertEquals("org.apache.commons.lang3", ClassUtils.getPackageName(new ClassUtils(), "<null>"));
+        assertEquals("org.apache.commons.lang3", ClassUtils.getPackageName(new Inner(), "<null>"));
         assertEquals("<null>", ClassUtils.getPackageName(null, "<null>"));
     }
     
@@ -162,7 +162,7 @@
     }
     
     public void test_getPackageName_String() {
-        assertEquals("org.apache.commons.lang", ClassUtils.getPackageName(ClassUtils.class.getName()));
+        assertEquals("org.apache.commons.lang3", ClassUtils.getPackageName(ClassUtils.class.getName()));
         assertEquals("java.util", ClassUtils.getPackageName(Map.Entry.class.getName()));
         assertEquals("", ClassUtils.getPackageName((String)null));
         assertEquals("", ClassUtils.getPackageName(""));
@@ -511,8 +511,8 @@
         assertEquals("String.class -> String.class",
             String.class, ClassUtils.primitiveToWrapper(String.class));
         assertEquals("ClassUtils.class -> ClassUtils.class",
-            org.apache.commons.lang.ClassUtils.class, 
-            ClassUtils.primitiveToWrapper(org.apache.commons.lang.ClassUtils.class));
+            org.apache.commons.lang3.ClassUtils.class, 
+            ClassUtils.primitiveToWrapper(org.apache.commons.lang3.ClassUtils.class));
         assertEquals("Void.TYPE -> Void.TYPE",
             Void.TYPE, ClassUtils.primitiveToWrapper(Void.TYPE));
             
@@ -773,11 +773,11 @@
     }
 
     public void test_getShortCanonicalName_String() {
-        assertEquals("ClassUtils", ClassUtils.getShortCanonicalName("org.apache.commons.lang.ClassUtils"));
-        assertEquals("ClassUtils[]", ClassUtils.getShortCanonicalName("[Lorg.apache.commons.lang.ClassUtils;"));
-        assertEquals("ClassUtils[][]", ClassUtils.getShortCanonicalName("[[Lorg.apache.commons.lang.ClassUtils;"));
-        assertEquals("ClassUtils[]", ClassUtils.getShortCanonicalName("org.apache.commons.lang.ClassUtils[]"));
-        assertEquals("ClassUtils[][]", ClassUtils.getShortCanonicalName("org.apache.commons.lang.ClassUtils[][]"));
+        assertEquals("ClassUtils", ClassUtils.getShortCanonicalName("org.apache.commons.lang3.ClassUtils"));
+        assertEquals("ClassUtils[]", ClassUtils.getShortCanonicalName("[Lorg.apache.commons.lang3.ClassUtils;"));
+        assertEquals("ClassUtils[][]", ClassUtils.getShortCanonicalName("[[Lorg.apache.commons.lang3.ClassUtils;"));
+        assertEquals("ClassUtils[]", ClassUtils.getShortCanonicalName("org.apache.commons.lang3.ClassUtils[]"));
+        assertEquals("ClassUtils[][]", ClassUtils.getShortCanonicalName("org.apache.commons.lang3.ClassUtils[][]"));
         assertEquals("int[]", ClassUtils.getShortCanonicalName("[I"));
         assertEquals("int[][]", ClassUtils.getShortCanonicalName("[[I"));
         assertEquals("int[]", ClassUtils.getShortCanonicalName("int[]"));
@@ -786,32 +786,32 @@
 
     public void test_getPackageCanonicalName_Object() {
         assertEquals("<null>", ClassUtils.getPackageCanonicalName(null, "<null>"));
-        assertEquals("org.apache.commons.lang", ClassUtils.getPackageCanonicalName(new ClassUtils(), "<null>"));
-        assertEquals("org.apache.commons.lang", ClassUtils.getPackageCanonicalName(new ClassUtils[0], "<null>"));
-        assertEquals("org.apache.commons.lang", ClassUtils.getPackageCanonicalName(new ClassUtils[0][0], "<null>"));
+        assertEquals("org.apache.commons.lang3", ClassUtils.getPackageCanonicalName(new ClassUtils(), "<null>"));
+        assertEquals("org.apache.commons.lang3", ClassUtils.getPackageCanonicalName(new ClassUtils[0], "<null>"));
+        assertEquals("org.apache.commons.lang3", ClassUtils.getPackageCanonicalName(new ClassUtils[0][0], "<null>"));
         assertEquals("", ClassUtils.getPackageCanonicalName(new int[0], "<null>"));
         assertEquals("", ClassUtils.getPackageCanonicalName(new int[0][0], "<null>"));
     }
 
     public void test_getPackageCanonicalName_Class() {
-        assertEquals("org.apache.commons.lang", ClassUtils.getPackageCanonicalName(ClassUtils.class));
-        assertEquals("org.apache.commons.lang", ClassUtils.getPackageCanonicalName(ClassUtils[].class));
-        assertEquals("org.apache.commons.lang", ClassUtils.getPackageCanonicalName(ClassUtils[][].class));
+        assertEquals("org.apache.commons.lang3", ClassUtils.getPackageCanonicalName(ClassUtils.class));
+        assertEquals("org.apache.commons.lang3", ClassUtils.getPackageCanonicalName(ClassUtils[].class));
+        assertEquals("org.apache.commons.lang3", ClassUtils.getPackageCanonicalName(ClassUtils[][].class));
         assertEquals("", ClassUtils.getPackageCanonicalName(int[].class));
         assertEquals("", ClassUtils.getPackageCanonicalName(int[][].class));
     }
 
     public void test_getPackageCanonicalName_String() {
-        assertEquals("org.apache.commons.lang", 
-            ClassUtils.getPackageCanonicalName("org.apache.commons.lang.ClassUtils"));
-        assertEquals("org.apache.commons.lang", 
-            ClassUtils.getPackageCanonicalName("[Lorg.apache.commons.lang.ClassUtils;"));
-        assertEquals("org.apache.commons.lang", 
-            ClassUtils.getPackageCanonicalName("[[Lorg.apache.commons.lang.ClassUtils;"));
-        assertEquals("org.apache.commons.lang", 
-            ClassUtils.getPackageCanonicalName("org.apache.commons.lang.ClassUtils[]"));
-        assertEquals("org.apache.commons.lang", 
-            ClassUtils.getPackageCanonicalName("org.apache.commons.lang.ClassUtils[][]"));
+        assertEquals("org.apache.commons.lang3", 
+            ClassUtils.getPackageCanonicalName("org.apache.commons.lang3.ClassUtils"));
+        assertEquals("org.apache.commons.lang3", 
+            ClassUtils.getPackageCanonicalName("[Lorg.apache.commons.lang3.ClassUtils;"));
+        assertEquals("org.apache.commons.lang3", 
+            ClassUtils.getPackageCanonicalName("[[Lorg.apache.commons.lang3.ClassUtils;"));
+        assertEquals("org.apache.commons.lang3", 
+            ClassUtils.getPackageCanonicalName("org.apache.commons.lang3.ClassUtils[]"));
+        assertEquals("org.apache.commons.lang3", 
+            ClassUtils.getPackageCanonicalName("org.apache.commons.lang3.ClassUtils[][]"));
         assertEquals("", ClassUtils.getPackageCanonicalName("[I"));
         assertEquals("", ClassUtils.getPackageCanonicalName("[[I"));
         assertEquals("", ClassUtils.getPackageCanonicalName("int[]"));
@@ -34,7 +34,7 @@
 
 /**
- * Unit tests {@link org.apache.commons.lang.ClassUtils}.
+ * Unit tests {@link org.apache.commons.lang3.ClassUtils}.
  *
  * @author Apache Software Foundation

Modified: commons/proper/lang/trunk/src/test/org/apache/commons/lang3/EnumUtilsTest.java
URL: http://svn.apache.org/viewvc/commons/proper/lang/trunk/src/test/org/apache/commons/lang3/EnumUtilsTest.java?rev=889215&r1=889214&r2=889215&view=diff
==============================================================================